import { actionResult, actionResultError, actionResultErrorFromCaughtError, qpqCoreUtils, UserDirectoryActionType, UserDirectoryAuthenticateUserErrorTypeEnum, } from 'quidproquo-core';
import { getCFExportNameUserPoolClientIdFromConfig, getCFExportNameUserPoolIdFromConfig } from '../../../awsNamingUtils';
import { getExportedValue } from '../../../logic/cloudformation/getExportedValue';
import { authenticateUser } from '../../../logic/cognito/authenticateUser';
const getProcessAuthenticateUser = (qpqConfig) => {
    return async (payload) => {
        const region = qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const userPoolId = await getExportedValue(getCFExportNameUserPoolIdFromConfig(payload.userDirectoryName, qpqConfig), region);
        const userPoolClientId = await getExportedValue(getCFExportNameUserPoolClientIdFromConfig(payload.userDirectoryName, qpqConfig), region);
        try {
            const authResponse = await authenticateUser(userPoolId, userPoolClientId, qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig), payload.authenticateUserRequest.isCustom, payload.authenticateUserRequest.email, payload.authenticateUserRequest.password);
            return actionResult(authResponse);
        }
        catch (error) {
            return actionResultErrorFromCaughtError(error, {
                UserNotFoundException: () => actionResultError(UserDirectoryAuthenticateUserErrorTypeEnum.UserNotFound, 'Incorrect username or password'),
                NotAuthorizedException: () => actionResultError(UserDirectoryAuthenticateUserErrorTypeEnum.UserNotFound, 'Incorrect username or password'),
            });
        }
    };
};
export const getUserDirectoryAuthenticateUserActionProcessor = async (qpqConfig) => ({
    [UserDirectoryActionType.AuthenticateUser]: getProcessAuthenticateUser(qpqConfig),
});
