import { actionResult, actionResultError, ErrorTypeEnum, qpqCoreUtils, UserDirectoryActionType, } from 'quidproquo-core';
import { getCFExportNameUserPoolClientIdFromConfig, getCFExportNameUserPoolIdFromConfig } from '../../../awsNamingUtils';
import { getExportedValue } from '../../../logic/cloudformation/getExportedValue';
import { refreshToken as cognitoRefreshToken } from '../../../logic/cognito/refreshToken';
const getProcessRefreshToken = (qpqConfig) => {
    return async ({ userDirectoryName, refreshToken }, session) => {
        const region = qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const userPoolId = await getExportedValue(getCFExportNameUserPoolIdFromConfig(userDirectoryName, qpqConfig), region);
        const userPoolClientId = await getExportedValue(getCFExportNameUserPoolClientIdFromConfig(userDirectoryName, qpqConfig), region);
        if (!session.decodedAccessToken || !session.decodedAccessToken.username) {
            return actionResultError(ErrorTypeEnum.Unauthorized, 'Invalid accessToken');
        }
        const authResponse = await cognitoRefreshToken(userPoolId, userPoolClientId, qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig), session.decodedAccessToken.username, refreshToken);
        return actionResult(authResponse);
    };
};
export const getUserDirectoryRefreshTokenActionProcessor = async (qpqConfig) => ({
    [UserDirectoryActionType.RefreshToken]: getProcessRefreshToken(qpqConfig),
});
